==> ldap-account-manager_6.7.orig.tar.bz2: ldap-account-manager-6.7/templates/lib/extra/ckeditor/plugins/link/lang/bs.js <==
﻿/*
Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'link', 'bs', {
	acccessKey: 'Pristupna tipka',
	advanced: 'Naprednije',
	advisoryContentType: 'Advisory vrsta sadržaja',
	advisoryTitle: 'Advisory title',
	anchor: {
		toolbar: 'Anchor',
		menu: 'Edit Anchor',
		title: 'Anchor Properties',
		name: 'Anchor Name',
		errorName: 'Please type the anchor name',
		remove: 'Remove Anchor'
	},
	anchorId: 'Po Id-u elementa',
	anchorName: 'Po nazivu sidra',
	charset: 'Linked Resource Charset',
	cssClasses: 'Klase CSS stilova',
	download: 'Force Download', // MISSING
	displayText: 'Display Text', // MISSING
	emailAddress: 'E-Mail Adresa',
	emailBody: 'Poruka',
	emailSubject: 'Subjekt poruke',
	id: 'Id',
	info: 'Link info',
	langCode: 'Smjer pisanja',
	langDir: 'Smjer pisanja',
	langDirLTR: 'S lijeva na desno (LTR)',
	langDirRTL: 'S desna na lijevo (RTL)',
	menu: 'Izmjeni link',
	name: 'Naziv',
	noAnchors: '(Nema dostupnih sidra na stranici)',
	noEmail: 'Molimo ukucajte e-mail adresu',
	noUrl: 'Molimo ukucajte URL link',
	other: '<other>', // MISSING
	popupDependent: 'Ovisno (Netscape)',
	popupFeatures: 'Moguænosti popup prozora',
	popupFullScreen: 'Cijeli ekran (IE)',
	popupLeft: 'Lijeva pozicija',
	popupLocationBar: 'Traka za lokaciju',
	popupMenuBar: 'Izborna traka',
	popupResizable: 'Resizable', // MISSING
	popupScrollBars: 'Scroll traka',
	popupStatusBar: 'Statusna traka',
	popupToolbar: 'Traka sa alatima',
	popupTop: 'Gornja pozicija',
	rel: 'Relationship', // MISSING
	selectAnchor: 'Izaberi sidro',
	styles: 'Stil',
	tabIndex: 'Tab indeks',
	target: 'Prozor',
	targetFrame: '<frejm>',
	targetFrameName: 'Target Frame Name', // MISSING
	targetPopup: '<popup prozor>',
	targetPopupName: 'Naziv popup prozora',
	title: 'Link',
	toAnchor: 'Sidro na ovoj stranici',
	toEmail: 'E-Mail',
	toUrl: 'URL',
	toolbar: 'Ubaci/Izmjeni link',
	type: 'Tip linka',
	unlink: 'Izbriši link',
	upload: 'Šalji'
} );

==> ldap-account-manager_8.5.orig.tar.bz2: ldap-account-manager-8.5/templates/lib/extra/ckeditor/plugins/link/lang/bs.js <==
﻿/*
Copyright (c) 2003-2023, CKSource Holding sp. z o.o. All rights reserved.
CKEditor 4 LTS ("Long Term Support") is available under the terms of the Extended Support Model.
*/
CKEDITOR.plugins.setLang( 'link', 'bs', {
	acccessKey: 'Pristupna tipka',
	advanced: 'Naprednije',
	advisoryContentType: 'Advisory vrsta sadržaja',
	advisoryTitle: 'Advisory title',
	anchor: {
		toolbar: 'Anchor',
		menu: 'Edit Anchor',
		title: 'Anchor Properties',
		name: 'Anchor Name',
		errorName: 'Please type the anchor name',
		errorWhitespace: 'Anchor name cannot contain space characters', // MISSING
		remove: 'Remove Anchor'
	},
	anchorId: 'Po Id-u elementa',
	anchorName: 'Po nazivu sidra',
	charset: 'Linked Resource Charset',
	cssClasses: 'Klase CSS stilova',
	download: 'Force Download', // MISSING
	displayText: 'Display Text', // MISSING
	emailAddress: 'E-Mail Adresa',
	emailBody: 'Poruka',
	emailSubject: 'Subjekt poruke',
	id: 'Id',
	info: 'Link info',
	langCode: 'Smjer pisanja',
	langDir: 'Smjer pisanja',
	langDirLTR: 'S lijeva na desno (LTR)',
	langDirRTL: 'S desna na lijevo (RTL)',
	menu: 'Izmjeni link',
	name: 'Naziv',
	noAnchors: '(Nema dostupnih sidra na stranici)',
	noEmail: 'Molimo ukucajte e-mail adresu',
	noUrl: 'Molimo ukucajte URL link',
	noTel: 'Please type the phone number', // MISSING
	other: '<other>', // MISSING
	phoneNumber: 'Phone number', // MISSING
	popupDependent: 'Ovisno (Netscape)',
	popupFeatures: 'Moguænosti popup prozora',
	popupFullScreen: 'Cijeli ekran (IE)',
	popupLeft: 'Lijeva pozicija',
	popupLocationBar: 'Traka za lokaciju',
	popupMenuBar: 'Izborna traka',
	popupResizable: 'Resizable', // MISSING
	popupScrollBars: 'Scroll traka',
	popupStatusBar: 'Statusna traka',
	popupToolbar: 'Traka sa alatima',
	popupTop: 'Gornja pozicija',
	rel: 'Relationship', // MISSING
	selectAnchor: 'Izaberi sidro',
	styles: 'Stil',
	tabIndex: 'Tab indeks',
	target: 'Prozor',
	targetFrame: '<frejm>',
	targetFrameName: 'Target Frame Name', // MISSING
	targetPopup: '<popup prozor>',
	targetPopupName: 'Naziv popup prozora',
	title: 'Link',
	toAnchor: 'Sidro na ovoj stranici',
	toEmail: 'E-Mail',
	toUrl: 'URL',
	toPhone: 'Phone', // MISSING
	toolbar: 'Ubaci/Izmjeni link',
	type: 'Tip linka',
	unlink: 'Izbriši link',
	upload: 'Šalji'
} );
